<?php
/**
 * Plugin Name: Show Downloads for Admin (EasyToolsWP)
 * Description: Displays download files on product pages in the frontend, but only for administrators.
 * Version: 1.1
 * Author: EasyToolsWP
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Hook into WooCommerce's single product summary to add our function
add_action( 'woocommerce_single_product_summary', 'show_downloads_for_admin', 25 );

function show_downloads_for_admin() {
    // Check if the current user is an administrator
    if ( current_user_can( 'administrator' ) ) {
        global $product;

        // Get the download files for the product
        $downloads = $product->get_downloads();

        if ( ! empty( $downloads ) ) {
            ?>
            <style>
                .admin-downloads {
                    margin-top: 20px;
					margin-bottom:20px;
                    padding: 20px;
                    border: 1px solid #ddd;
                    border-radius: 5px;
                    background-color: #f9f9f9;
                }
                .admin-downloads h3 {
                    margin-top: 0;
                    font-size: 18px;
                    color: #333;
                }
                .admin-downloads ul {
                    list-style-type: none;
                    padding-left: 0;
                }
                .admin-downloads li {
                    margin-bottom: 10px;
                }
                .admin-downloads a {
                    color: #0073aa;
                    text-decoration: none;
                }
                .admin-downloads a:hover {
                    text-decoration: underline;
                }
            </style>
            <div class="admin-downloads">
                <h3>Download Files:</h3>
                <ul>
                    <?php foreach ( $downloads as $download ) : ?>
                        <li><a href="<?php echo esc_url( $download['file'] ); ?>"><?php echo esc_html( $download['name'] ); ?></a></li>
                    <?php endforeach; ?>
                </ul>
            </div>
            <?php
        }
    }
}
